@@ -26,14 +26,6 @@ conditional.test = function(x, y, sx, data, test, B, alpha = 1, learning = TRUE)
       df = (nlevels(datax) - 1) * (nlevels(datay) - 1)
       p.value = pchisq(statistic, df, lower.tail = FALSE)
 
-    }#THEN
-    # Akaike Information Criterion-like test (binary, no p-value!)
-    else if (test == "aict") {
-
-      statistic = mi.test(datax, datay, ndata, gsquare = FALSE) <
-               (nlevels(datax) - 1) * (nlevels(datay) - 1) / ndata
-      p.value = as.integer(statistic)
-
     }#THEN
     # Shrinked Mutual Infomation (chi-square asymptotic distribution)
     if (test == "mi-sh") {
@@ -153,17 +145,6 @@ conditional.test = function(x, y, sx, data, test, B, alpha = 1, learning = TRUE)
       df = (nlevels(datax) - 1) * (nlevels(datay) - 1) * nlevels(config)
       p.value = pchisq(statistic, df, lower.tail = FALSE)
 
-    }#THEN
-    # Conditional Akaike Information Criterion-like test (binary, no p-value!)
-    else if (test == "aict") {
-
-      datax = minimal.data.frame.column(data, x)
-      datay = minimal.data.frame.column(data, y)
-
-      statistic = cmi.test(datax, datay, config, ndata, gsquare = FALSE) <
-               (nlevels(datax) - 1) * (nlevels(datay) - 1) * nlevels(config) / ndata
-      p.value = as.integer(statistic)
-
     }#THEN
     # Shrinked Conditional Mutual Infomation (chi-square asymptotic distribution)
     if (test == "mi-sh") {
@@ -288,13 +269,6 @@ conditional.test = function(x, y, sx, data, test, B, alpha = 1, learning = TRUE)
   }#THEN
   else {
 
-    if (test %in% c("aict")) {
-
-      statistic = as.logical(statistic)
-      p.value = NA
-
-    }#THEN
-
     # build a valid object of class htest.
     result = structure(
         list(statistic = structure(statistic, names = test),
